#' Plot different types of surrogates
#'
#' Generates figures that illustrate surrogates that are good for individual-level, trial-level, both, or neither
#'
#' @param individual Logical. If true, surrogate is good for individual-level prediction
#' @param trial Logical. If true, surrogate is good for trial level prediction
#'
#' @export


plot_surrogates <- function(individual = FALSE, trial = FALSE){

  n <- 20
  TX <- c(rep(TRUE, n), rep(FALSE, n))
  X <- runif(2 * n, -1, 1) + ifelse(TX, 3, 0)
  if(individual) {
    muy <- individual *  X + ifelse(rep(trial, 2 * n), 0 * TX, -3.5 * TX)
  } else {
    muy <- ifelse(rep(trial, 2 * n), 2 * TX, 0 * TX)
  }
  Y <- runif(2 * n) + muy

  dta <- data.frame(TX, X, Y)

  thiscor <- ifelse(individual, .75, 0)
  el.dta <- data.frame()
  for(g in c(TRUE, FALSE)){
    el.dta <- rbind(el.dta, cbind(as.data.frame(with(dta[dta$TX==g,], ellipse::ellipse(thiscor,
                                                                               scale=c(sqrt(1/3),sqrt(1/ifelse(individual, 3, 10))),
                                                                               centre=c(mean(X),mean(Y))), level = .975)),group=g))
  }

  ggplot2::ggplot(dta, ggplot2::aes(x = X, y = Y, shape = TX)) + ggplot2::geom_point(position = "jitter") +
    ggplot2::scale_shape_manual(values = c(1, 4)) +
    ggplot2::scale_x_continuous("Candidate surrogate X", labels = NULL, breaks = NULL, limits = c(-1.75, 4.75)) +
    ggplot2::scale_y_continuous("Definitive Y", labels = NULL, breaks = NULL, limits = c(-1.5, 5)) + ggplot2::guides(shape = FALSE) +
    ggplot2::theme_bw() +
    ggplot2::geom_path(data=el.dta, ggplot2::aes(x=x, y=y, shape = group), linetype=1)


}